@@ -1,3 +1,4 @@
+import tempfile
 import time
 from pathlib import Path
 import os
@@ -192,6 +193,55 @@ class CacheWorkspace:
             self.cleanup()
 
 
+def save_to_project(save_fn: callable, file_path: str, *args, file_path_arg_pos: int = 0,
+                    cache_workspace: CacheWorkspace = None, path_to_datamover: str = '/sw/taurus/tools/slurmtools/default/bin/', path_to_workspace_tools: str = '/usr/bin/', **kw):
+    '''Save data to a project space.
+
+    Since we don't have direct access, we first save to a temporary file on a workspace and then copy to the project space.
+
+    Parameters
+    ----------
+    save_fn : callable
+        function that saves the data to a file. Must accept the file path as a string in a positional argument.
+    file_path : str
+        full path (on the project space) where the file should be saved
+    file_path_arg_pos : int, optional
+        position of the argument that defines the file path in `save_fn`
+    path_to_datamover : str, optional
+        path to the datamover tools, by default '/sw/taurus/tools/slurmtools/default/bin/'
+    path_to_workspace_tools: str, optional
+        path to the wrkspace tools, by default '/usr/bin/'
+    cache_workspace : CacheWorkspace, optional
+        A cache workspace on the cluster; if None is provided, a temporary workspace will be created and deleted once the process was successful, by default None
+    '''
+    file_path = file_path.replace("\\", "/")
+    full_path = Path(file_path)
+
+    cleanup_cache = False
+    if cache_workspace is None:
+        cleanup = False
+        cache_workspace = CacheWorkspace(path_to_exe=path_to_workspace_tools)
+    # if we have write access to the target directory, we can write directly
+    # there
+    if os.access(full_path.parent, os.W_OK):
+        args = args[0:file_path_arg_pos] + \
+            (str(full_path),) + args[file_path_arg_pos:]
+        return save_fn(*args, **kw)
+    # if the target is a write protected project space, we need to use the
+    # datamover tools
+    dm = Datamover(path_to_exe=path_to_datamover)
+    with tempfile.TemporaryDirectory(prefix=cache_workspace.name + '/') as tmp:
+        temp_file = Path(tmp.name) / full_path.name
+        args = args[0:file_path_arg_pos] + \
+            (str(temp_file),) + args[file_path_arg_pos:]
+        output = save_fn(*args, **kw)
+        waitfor(dm.dtcp(str(temp_file), str(full_path)))
+        print('target file: {}'.format(str(full_path)))
+    if cleanup:
+        cache_workspace.cleanup()
+    return output
+
+
 def waitfor(proc, timeout_in_s: float = -1,
             discard_output: bool = True) -> int:
     """
