@@ -15,11 +15,12 @@ class MockCluster:
         self.commands = commands
         self.src = self.mock_path / exe
 
-    def __enter__(self) -> None:
+    def __enter__(self):
         shutil.copytree(str(self.mock_path) + '_files', self.mock_path)
         src = self.mock_path / 'dtwrapper'
         for command in self.commands:
             os.symlink(src, self.mock_path / command)
+        return self
 
     def __exit__(self, exception_type, exception_value, traceback) -> None:
         shutil.rmtree(self.mock_path, ignore_errors=True)
